@@ -38,8 +38,7 @@ public:
         : Daemon(parent)
         , m_nam(nullptr)
     {
-        qApp->setWindowIcon(QIcon::fromTheme(QStringLiteral("kdeconnect"),
-            QIcon(QStandardPaths::locate(QStandardPaths::AppLocalDataLocation, QStringLiteral("icons/hicolor/scalable/apps/kdeconnect.svg")))));
+        qApp->setWindowIcon(QIcon(QStringLiteral(":/icons/kdeconnect/kdeconnect.svg")));
     }
 
     void askPairingConfirmation(Device* device) override
@@ -72,7 +71,7 @@ public:
     QNetworkAccessManager* networkAccessManager() override
     {
         if (!m_nam) {
-            m_nam = new KIO::AccessManager(this);
+            m_nam = new KIO::Integration::AccessManager(this);
         }
         return m_nam;
     }
@@ -164,6 +163,11 @@ int main(int argc, char* argv[])
 
     DesktopDaemon daemon;
 
+#ifdef Q_OS_WIN
+    // make sure indicator shows up in the tray whenever daemon is spawned
+    QProcess::startDetached(QStringLiteral("kdeconnect-indicator.exe"));
+#endif
+
     // kdeconnectd is autostarted, so disable session management to speed up startup
     auto disableSessionManagement = [](QSessionManager &sm) {
         sm.setRestartHint(QSessionManager::RestartNever);
