@@ -80,10 +80,12 @@ int main(int argc, char** argv)
         QObject::connect(configure, &QAction::triggered, configure, [&dialog]() {
             if (dialog == nullptr) {
                 dialog = new KCMultiDialog;
-                dialog->addModule(QStringLiteral("kcm_kdeconnect"));
+                dialog->addModule(KPluginMetaData(QStringLiteral("kcm_kdeconnect")));
                 dialog->setAttribute(Qt::WA_DeleteOnClose);
                 dialog->show();
+                dialog->raise();
             } else {
+                dialog->raise();
                 dialog->activateWindow();
             }
         });
@@ -141,11 +143,11 @@ int main(int argc, char** argv)
     QObject::connect(&model, &DevicesModel::rowsChanged, &model, [&systray, &model]() {
         systray.setToolTip(i18np("%1 device connected", "%1 devices connected", model.rowCount()));
     });
-    QObject::connect(&systray, &QSystemTrayIcon::activated, [&iface](QSystemTrayIcon::ActivationReason reason) {
+    QObject::connect(&systray, &QSystemTrayIcon::activated, [](QSystemTrayIcon::ActivationReason reason) {
         if (reason == QSystemTrayIcon::Trigger) {
             const QString kdeconnectAppExecutable = QStandardPaths::findExecutable(QStringLiteral("kdeconnect-app"), { QCoreApplication::applicationDirPath() });
             if (!kdeconnectAppExecutable.isEmpty()) {
-                QProcess::startDetached(kdeconnectAppExecutable);
+                QProcess::startDetached(kdeconnectAppExecutable, {});
             }
         }
     });
@@ -160,7 +162,9 @@ int main(int argc, char** argv)
     systray.setStandardActionsEnabled(false);
     QObject::connect(&model, &DevicesModel::rowsChanged, &model, [&systray, &model]() {
         const auto count = model.rowCount();
+#ifndef Q_OS_MACOS // On MacOS, setting status to Active disables color theme syncing of the menu icon
         systray.setStatus(count == 0 ? KStatusNotifierItem::Passive : KStatusNotifierItem::Active);
+#endif
         systray.setToolTip(QStringLiteral("kdeconnect"), QStringLiteral("KDE Connect"), i18np("%1 device connected", "%1 devices connected", count));
     });
 
