@@ -17,6 +17,8 @@
 
 int main(int argc, char** argv)
 {
+    QIcon::setFallbackThemeName(QStringLiteral("breeze"));
+
     QApplication app(argc, argv);
     app.setWindowIcon(QIcon::fromTheme(QStringLiteral("kdeconnect")));
     KAboutData about(QStringLiteral("kdeconnect-settings"),
@@ -37,13 +39,7 @@ int main(int argc, char** argv)
     KDBusService dbusService(KDBusService::Unique);
 
     KCMultiDialog* dialog = new KCMultiDialog;
-    dialog->addModule(QStringLiteral("kcm_kdeconnect"), {parser.value(QStringLiteral("args"))});
-
-    auto style = dialog->style();
-    dialog->setContentsMargins(style->pixelMetric(QStyle::PM_LayoutLeftMargin),
-                               style->pixelMetric(QStyle::PM_LayoutTopMargin),
-                               style->pixelMetric(QStyle::PM_LayoutRightMargin),
-                               style->pixelMetric(QStyle::PM_LayoutBottomMargin));
+    dialog->addModule(KPluginMetaData(QStringLiteral("kcm_kdeconnect")), {parser.value(QStringLiteral("args"))});
 
     dialog->setAttribute(Qt::WA_DeleteOnClose);
     dialog->show();
